@@ -1,10 +1,10 @@
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(Not currently on any branch)'
+__git_branch__ = '(detached from v0.1.2)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'c7494c96bdb43c52176034a6ad2f0ba6da2a1063'
-__git_head_subject__ = 'Finished release v0.1.1.'
+__git_head_hash__ = '62f7605210b77b7d8816ce74a5aca31ea9af1afd'
+__git_head_subject__ = 'Finished release v0.1.2.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
